:mod:`pyam`
***********

:doc:`Package documentation <pyam:index>`

.. currentmodule:: genno.compat.pyam

.. automodule:: genno.compat.pyam
   :members:

.. automodule:: genno.compat.pyam.computations
   :members:

.. automodule:: genno.compat.pyam.util
   :members:
